{% extends "base.html" %}
{% comment %}
# SPDX-License-Identifier: AGPL-3.0-or-later
{% endcomment %}

{% load bootstrap %}
{% load i18n %}

{% block content %}

  <h3>{{ title }}</h3>

  <p>
    {% trans "Are you sure that you want to delete this server?" %}
  </p>
  <div class="table-responsive">
    <table class="table">
      <tbody>
        <tr>
          <th>{% trans "Endpoint" %}</th>
          <td>{{ peer_endpoint }}</td>
        </tr>
        <tr>
          <th>{% trans "Public Key" %}</th>
          <td>{{ peer_public_key }}</td>
        </tr>
      </tbody>
    </table>
  </div>

  <form class="form form-delete-server" method="post">
    {% csrf_token %}

    <input type="submit" class="btn btn-danger"
           value="{% trans "Delete" %}"/>
  </form>

{% endblock %}
